import 'package:flutter/widgets.dart';

class BidirectionalPageView extends StatefulWidget {
  final _centerKey = UniqueKey();

  final bool reverse;

  final Axis scrollDirection;

  final SliverChildDelegate nextChildDelegate;
  final SliverChildDelegate previousChildDelegate;

  BidirectionalPageView({
    Key? key,
    this.reverse = false,
    this.scrollDirection = Axis.horizontal,
    required this.nextChildDelegate,
    required this.previousChildDelegate,
  }) : super(key: key);

  BidirectionalPageView.builder({
    Key? key,
    this.reverse = false,
    this.scrollDirection = Axis.horizontal,
    required IndexedWidgetBuilder builder,
  }): 
    nextChildDelegate = SliverChildBuilderDelegate(builder),
    previousChildDelegate = SliverChildBuilderDelegate((context, index) => builder(context, (index + 1) * -1)),
    super(key: key);

  @override
  State<StatefulWidget> createState() => _BidirectionalPageViewState();
}

class _BidirectionalPageViewState extends State<BidirectionalPageView> {
  @override
  Widget build(BuildContext context) {
    final axisDirection = inferAxisDirectionFromAxisAndContext(
      widget.scrollDirection,
      context,
      reverse: widget.reverse,
    );

    return NotificationListener<ScrollNotification>(
      onNotification: (ScrollNotification notification) {
        return false;
      },
      child: Scrollable(
        axisDirection: axisDirection,
        physics: PageScrollPhysics(),
        viewportBuilder: (context, position) => Viewport(
          axisDirection: axisDirection,
          center: widget._centerKey,
          offset: position,
          slivers: [
            SliverFillViewport(
              delegate: widget.previousChildDelegate,
            ),
            SliverFillViewport(
              key: widget._centerKey,
              delegate: widget.nextChildDelegate,
            ),
          ],
        ),
      ),
    );
  }
}

AxisDirection inferAxisDirectionFromAxisAndContext(
  Axis axis,
  BuildContext context, {
  bool reverse = false,
}) {
  switch (axis) {
    case Axis.horizontal:
      assert(debugCheckHasDirectionality(context));
      final textDirection = Directionality.of(context);
      final axisDirection =
          textDirectionToAxisDirection(textDirection);
      return reverse ? flipAxisDirection(axisDirection) : axisDirection;
    case Axis.vertical:
      return reverse ? AxisDirection.up : AxisDirection.down;
  }
}
