import 'package:fliwork_calendar/fliwork_calendar.dart';
import 'package:flutter/material.dart';

class CalendarBar extends StatefulWidget implements PreferredSizeWidget {
  final DateTime initialDate;

  CalendarBar({
    Key? key,
    DateTime? initialDate,
  })  : initialDate = initialDate ?? DateTime.now(),
        super(key: key);

  @override
  State<StatefulWidget> createState() => _CalendarBarState(
        selectedDate: initialDate,
      );

  @override
  Size get preferredSize => Size.fromHeight(72.0);
}

class _CalendarBarState extends State<CalendarBar> {
  final DateTime _selectedDate;

  _CalendarBarState({
    required DateTime selectedDate,
  }) : _selectedDate = selectedDate;

  Widget buildWeek(BuildContext context, DateTimeRange range) {
    return Row(
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
      children: Iterable.generate(
        range.duration.inDays,
        (index) => range.start.add(Duration(days: index)),
      )
          .map((date) => CalendarDayTile(
                active: DateUtils.isSameDay(_selectedDate, date),
                day: Text(FliworkCalendarLocalizations.of(context)!
                    .shortDayOfTheWeekFormat(date)),
                date: Text(FliworkCalendarLocalizations.of(context)!
                    .shortDateFormat(date)),
              ))
          .toList(),
    );
  }

  @override
  Widget build(BuildContext context) {
    final firstDay = firstDayOfWeek(
      _selectedDate,
      firstDayOfTheWeek: MaterialLocalizations.of(context).firstDayOfWeekIndex,
    );

    return SizedBox(
      height: 72.0,
      child: CalendarDurationView(
        duration: Duration(days: 7),
        initialDate: firstDay,
        builder: buildWeek,
      ),
    );
  }
}
