import 'package:flutter/material.dart';

class CalendarDayTile extends StatelessWidget {
  final bool active;
  final Widget day;
  final Widget date;

  CalendarDayTile({
    this.active = false,
    required this.day,
    required this.date,
  });

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);

    const animationDuration = Duration(milliseconds: 500);

    final boxColor = active ? theme.colorScheme.secondary : null;
    final textColor = active ? theme.colorScheme.onSecondary : null;

    final dayTextStyle = (theme.textTheme.bodyText2 ?? DefaultTextStyle.of(context).style).copyWith(
      color: textColor,
    );
    final dateTextStyle = (theme.textTheme.bodyText2 ?? DefaultTextStyle.of(context).style).copyWith(
      color: textColor,
    );

    return AnimatedContainer(
      duration: animationDuration,
      margin: EdgeInsets.symmetric(vertical: 8),
      padding: EdgeInsets.symmetric(horizontal: 8),
      decoration: BoxDecoration(
        color: boxColor,
        borderRadius: BorderRadius.circular(8),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          AnimatedDefaultTextStyle(
            duration: animationDuration,
            style: dayTextStyle,
            child: day,
          ),
          AnimatedDefaultTextStyle(
            duration: animationDuration,
            style: dateTextStyle,
            child: date,
          ),
        ],
      ),
    );
  }
}
