import 'package:flutter/material.dart';

/// Calculates the next first day of the Week.
///
/// [date.weekday] Monday = 1, ..., Sunday = 7
/// [firstDayOfTheWeek] compatible with [MaterialLocalizations.firstDayOfTheWeek] Sunday = 0, ..., Saturday = 6
///
/// [date.weekday] - [firstDayOfTheWeek] =
/// Sun (7) - Sun (0) = 7 % 7 = 0
/// Mon (1) - Sun (0) = 1 % 7 = 1 -> select the previous sunday 1 day ago
///
/// Mon (1) - Mon (1) = 0 % 7 = 0
/// Sun (7) - Mon (1) = 6 % 7 = 6 -> select the previous monday 6 days ago
DateTime firstDayOfWeek(
  DateTime date, {
  int firstDayOfTheWeek = 1,
}) {
  final offset = (date.weekday - firstDayOfTheWeek) % 7;

  return date.subtract(Duration(
    days: offset,
  ));
}